import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ServiceUsageResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            filter: str = ...,
            name: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListOperationsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListOperationsResponseHttpRequest,
            previous_response: ListOperationsResponse,
        ) -> ListOperationsResponseHttpRequest | None: ...

    @typing.type_check_only
    class ServicesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ConsumerQuotaMetricsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class LimitsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class AdminOverridesResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: QuotaOverride = ...,
                        force: bool = ...,
                        forceOnly: typing_extensions.Literal[
                            "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                            "LIMIT_DECREASE_BELOW_USAGE",
                            "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                        ]
                        | _list[
                            typing_extensions.Literal[
                                "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                                "LIMIT_DECREASE_BELOW_USAGE",
                                "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                            ]
                        ] = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self,
                        *,
                        name: str,
                        force: bool = ...,
                        forceOnly: typing_extensions.Literal[
                            "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                            "LIMIT_DECREASE_BELOW_USAGE",
                            "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                        ]
                        | _list[
                            typing_extensions.Literal[
                                "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                                "LIMIT_DECREASE_BELOW_USAGE",
                                "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                            ]
                        ] = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListAdminOverridesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListAdminOverridesResponseHttpRequest,
                        previous_response: ListAdminOverridesResponse,
                    ) -> ListAdminOverridesResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: QuotaOverride = ...,
                        force: bool = ...,
                        forceOnly: typing_extensions.Literal[
                            "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                            "LIMIT_DECREASE_BELOW_USAGE",
                            "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                        ]
                        | _list[
                            typing_extensions.Literal[
                                "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                                "LIMIT_DECREASE_BELOW_USAGE",
                                "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                            ]
                        ] = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                @typing.type_check_only
                class ConsumerOverridesResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: QuotaOverride = ...,
                        force: bool = ...,
                        forceOnly: typing_extensions.Literal[
                            "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                            "LIMIT_DECREASE_BELOW_USAGE",
                            "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                        ]
                        | _list[
                            typing_extensions.Literal[
                                "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                                "LIMIT_DECREASE_BELOW_USAGE",
                                "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                            ]
                        ] = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self,
                        *,
                        name: str,
                        force: bool = ...,
                        forceOnly: typing_extensions.Literal[
                            "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                            "LIMIT_DECREASE_BELOW_USAGE",
                            "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                        ]
                        | _list[
                            typing_extensions.Literal[
                                "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                                "LIMIT_DECREASE_BELOW_USAGE",
                                "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                            ]
                        ] = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListConsumerOverridesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListConsumerOverridesResponseHttpRequest,
                        previous_response: ListConsumerOverridesResponse,
                    ) -> ListConsumerOverridesResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: QuotaOverride = ...,
                        force: bool = ...,
                        forceOnly: typing_extensions.Literal[
                            "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                            "LIMIT_DECREASE_BELOW_USAGE",
                            "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                        ]
                        | _list[
                            typing_extensions.Literal[
                                "QUOTA_SAFETY_CHECK_UNSPECIFIED",
                                "LIMIT_DECREASE_BELOW_USAGE",
                                "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH",
                            ]
                        ] = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                def get(
                    self,
                    *,
                    name: str,
                    view: typing_extensions.Literal[
                        "QUOTA_VIEW_UNSPECIFIED", "BASIC", "FULL"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> ConsumerQuotaLimitHttpRequest: ...
                def adminOverrides(self) -> AdminOverridesResource: ...
                def consumerOverrides(self) -> ConsumerOverridesResource: ...

            def get(
                self,
                *,
                name: str,
                view: typing_extensions.Literal[
                    "QUOTA_VIEW_UNSPECIFIED", "BASIC", "FULL"
                ] = ...,
                **kwargs: typing.Any
            ) -> ConsumerQuotaMetricHttpRequest: ...
            def importAdminOverrides(
                self,
                *,
                parent: str,
                body: ImportAdminOverridesRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def importConsumerOverrides(
                self,
                *,
                parent: str,
                body: ImportConsumerOverridesRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal[
                    "QUOTA_VIEW_UNSPECIFIED", "BASIC", "FULL"
                ] = ...,
                **kwargs: typing.Any
            ) -> ListConsumerQuotaMetricsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListConsumerQuotaMetricsResponseHttpRequest,
                previous_response: ListConsumerQuotaMetricsResponse,
            ) -> ListConsumerQuotaMetricsResponseHttpRequest | None: ...
            def limits(self) -> LimitsResource: ...

        def batchEnable(
            self,
            *,
            parent: str,
            body: BatchEnableServicesRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def disable(
            self, *, name: str, body: DisableServiceRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def enable(
            self, *, name: str, body: EnableServiceRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def generateServiceIdentity(
            self, *, parent: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> ServiceHttpRequest: ...
        def list(
            self,
            *,
            parent: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListServicesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListServicesResponseHttpRequest,
            previous_response: ListServicesResponse,
        ) -> ListServicesResponseHttpRequest | None: ...
        def consumerQuotaMetrics(self) -> ConsumerQuotaMetricsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def operations(self) -> OperationsResource: ...
    def services(self) -> ServicesResource: ...

@typing.type_check_only
class ConsumerQuotaLimitHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ConsumerQuotaLimit: ...

@typing.type_check_only
class ConsumerQuotaMetricHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ConsumerQuotaMetric: ...

@typing.type_check_only
class ListAdminOverridesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAdminOverridesResponse: ...

@typing.type_check_only
class ListConsumerOverridesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListConsumerOverridesResponse: ...

@typing.type_check_only
class ListConsumerQuotaMetricsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListConsumerQuotaMetricsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListServicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListServicesResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class ServiceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Service: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AdExchangeBuyerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        def get(self, *, id: int, **kwargs: typing.Any) -> AccountHttpRequest: ...
        def list(self, **kwargs: typing.Any) -> AccountsListHttpRequest: ...
        def patch(
            self,
            *,
            id: int,
            body: Account = ...,
            confirmUnsafeAccountChange: bool = ...,
            **kwargs: typing.Any
        ) -> AccountHttpRequest: ...
        def update(
            self,
            *,
            id: int,
            body: Account = ...,
            confirmUnsafeAccountChange: bool = ...,
            **kwargs: typing.Any
        ) -> AccountHttpRequest: ...

    @typing.type_check_only
    class BillingInfoResource(googleapiclient.discovery.Resource):
        def get(
            self, *, accountId: int, **kwargs: typing.Any
        ) -> BillingInfoHttpRequest: ...
        def list(self, **kwargs: typing.Any) -> BillingInfoListHttpRequest: ...

    @typing.type_check_only
    class BudgetResource(googleapiclient.discovery.Resource):
        def get(
            self, *, accountId: str, billingId: str, **kwargs: typing.Any
        ) -> BudgetHttpRequest: ...
        def patch(
            self,
            *,
            accountId: str,
            billingId: str,
            body: Budget = ...,
            **kwargs: typing.Any
        ) -> BudgetHttpRequest: ...
        def update(
            self,
            *,
            accountId: str,
            billingId: str,
            body: Budget = ...,
            **kwargs: typing.Any
        ) -> BudgetHttpRequest: ...

    @typing.type_check_only
    class CreativesResource(googleapiclient.discovery.Resource):
        def addDeal(
            self,
            *,
            accountId: int,
            buyerCreativeId: str,
            dealId: str,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, accountId: int, buyerCreativeId: str, **kwargs: typing.Any
        ) -> CreativeHttpRequest: ...
        def insert(
            self, *, body: Creative = ..., **kwargs: typing.Any
        ) -> CreativeHttpRequest: ...
        def list(
            self,
            *,
            accountId: int | _list[int] = ...,
            buyerCreativeId: str | _list[str] = ...,
            dealsStatusFilter: typing_extensions.Literal[
                "approved", "conditionally_approved", "disapproved", "not_checked"
            ] = ...,
            maxResults: int = ...,
            openAuctionStatusFilter: typing_extensions.Literal[
                "approved", "conditionally_approved", "disapproved", "not_checked"
            ] = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> CreativesListHttpRequest: ...
        def list_next(
            self,
            previous_request: CreativesListHttpRequest,
            previous_response: CreativesList,
        ) -> CreativesListHttpRequest | None: ...
        def listDeals(
            self, *, accountId: int, buyerCreativeId: str, **kwargs: typing.Any
        ) -> CreativeDealIdsHttpRequest: ...
        def removeDeal(
            self,
            *,
            accountId: int,
            buyerCreativeId: str,
            dealId: str,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class MarketplacedealsResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            proposalId: str,
            body: DeleteOrderDealsRequest = ...,
            **kwargs: typing.Any
        ) -> DeleteOrderDealsResponseHttpRequest: ...
        def insert(
            self,
            *,
            proposalId: str,
            body: AddOrderDealsRequest = ...,
            **kwargs: typing.Any
        ) -> AddOrderDealsResponseHttpRequest: ...
        def list(
            self, *, proposalId: str, pqlQuery: str = ..., **kwargs: typing.Any
        ) -> GetOrderDealsResponseHttpRequest: ...
        def update(
            self,
            *,
            proposalId: str,
            body: EditAllOrderDealsRequest = ...,
            **kwargs: typing.Any
        ) -> EditAllOrderDealsResponseHttpRequest: ...

    @typing.type_check_only
    class MarketplacenotesResource(googleapiclient.discovery.Resource):
        def insert(
            self,
            *,
            proposalId: str,
            body: AddOrderNotesRequest = ...,
            **kwargs: typing.Any
        ) -> AddOrderNotesResponseHttpRequest: ...
        def list(
            self, *, proposalId: str, pqlQuery: str = ..., **kwargs: typing.Any
        ) -> GetOrderNotesResponseHttpRequest: ...

    @typing.type_check_only
    class MarketplaceprivateauctionResource(googleapiclient.discovery.Resource):
        def updateproposal(
            self,
            *,
            privateAuctionId: str,
            body: UpdatePrivateAuctionProposalRequest = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class PerformanceReportResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            accountId: str,
            endDateTime: str,
            startDateTime: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> PerformanceReportListHttpRequest: ...

    @typing.type_check_only
    class PretargetingConfigResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, accountId: str, configId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, accountId: str, configId: str, **kwargs: typing.Any
        ) -> PretargetingConfigHttpRequest: ...
        def insert(
            self,
            *,
            accountId: str,
            body: PretargetingConfig = ...,
            **kwargs: typing.Any
        ) -> PretargetingConfigHttpRequest: ...
        def list(
            self, *, accountId: str, **kwargs: typing.Any
        ) -> PretargetingConfigListHttpRequest: ...
        def patch(
            self,
            *,
            accountId: str,
            configId: str,
            body: PretargetingConfig = ...,
            **kwargs: typing.Any
        ) -> PretargetingConfigHttpRequest: ...
        def update(
            self,
            *,
            accountId: str,
            configId: str,
            body: PretargetingConfig = ...,
            **kwargs: typing.Any
        ) -> PretargetingConfigHttpRequest: ...

    @typing.type_check_only
    class ProductsResource(googleapiclient.discovery.Resource):
        def get(
            self, *, productId: str, **kwargs: typing.Any
        ) -> ProductHttpRequest: ...
        def search(
            self, *, pqlQuery: str = ..., **kwargs: typing.Any
        ) -> GetOffersResponseHttpRequest: ...

    @typing.type_check_only
    class ProposalsResource(googleapiclient.discovery.Resource):
        def get(
            self, *, proposalId: str, **kwargs: typing.Any
        ) -> ProposalHttpRequest: ...
        def insert(
            self, *, body: CreateOrdersRequest = ..., **kwargs: typing.Any
        ) -> CreateOrdersResponseHttpRequest: ...
        def patch(
            self,
            *,
            proposalId: str,
            revisionNumber: str,
            updateAction: typing_extensions.Literal[
                "accept",
                "cancel",
                "propose",
                "proposeAndAccept",
                "unknownAction",
                "updateNonTerms",
            ],
            body: Proposal = ...,
            **kwargs: typing.Any
        ) -> ProposalHttpRequest: ...
        def search(
            self, *, pqlQuery: str = ..., **kwargs: typing.Any
        ) -> GetOrdersResponseHttpRequest: ...
        def setupcomplete(
            self, *, proposalId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def update(
            self,
            *,
            proposalId: str,
            revisionNumber: str,
            updateAction: typing_extensions.Literal[
                "accept",
                "cancel",
                "propose",
                "proposeAndAccept",
                "unknownAction",
                "updateNonTerms",
            ],
            body: Proposal = ...,
            **kwargs: typing.Any
        ) -> ProposalHttpRequest: ...

    @typing.type_check_only
    class PubprofilesResource(googleapiclient.discovery.Resource):
        def list(
            self, *, accountId: int, **kwargs: typing.Any
        ) -> GetPublisherProfilesByAccountIdResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...
    def billingInfo(self) -> BillingInfoResource: ...
    def budget(self) -> BudgetResource: ...
    def creatives(self) -> CreativesResource: ...
    def marketplacedeals(self) -> MarketplacedealsResource: ...
    def marketplacenotes(self) -> MarketplacenotesResource: ...
    def marketplaceprivateauction(self) -> MarketplaceprivateauctionResource: ...
    def performanceReport(self) -> PerformanceReportResource: ...
    def pretargetingConfig(self) -> PretargetingConfigResource: ...
    def products(self) -> ProductsResource: ...
    def proposals(self) -> ProposalsResource: ...
    def pubprofiles(self) -> PubprofilesResource: ...

@typing.type_check_only
class AccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Account: ...

@typing.type_check_only
class AccountsListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountsList: ...

@typing.type_check_only
class AddOrderDealsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AddOrderDealsResponse: ...

@typing.type_check_only
class AddOrderNotesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AddOrderNotesResponse: ...

@typing.type_check_only
class BillingInfoHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BillingInfo: ...

@typing.type_check_only
class BillingInfoListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BillingInfoList: ...

@typing.type_check_only
class BudgetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Budget: ...

@typing.type_check_only
class CreateOrdersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CreateOrdersResponse: ...

@typing.type_check_only
class CreativeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Creative: ...

@typing.type_check_only
class CreativeDealIdsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CreativeDealIds: ...

@typing.type_check_only
class CreativesListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CreativesList: ...

@typing.type_check_only
class DeleteOrderDealsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DeleteOrderDealsResponse: ...

@typing.type_check_only
class EditAllOrderDealsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EditAllOrderDealsResponse: ...

@typing.type_check_only
class GetOffersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetOffersResponse: ...

@typing.type_check_only
class GetOrderDealsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetOrderDealsResponse: ...

@typing.type_check_only
class GetOrderNotesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetOrderNotesResponse: ...

@typing.type_check_only
class GetOrdersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetOrdersResponse: ...

@typing.type_check_only
class GetPublisherProfilesByAccountIdResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetPublisherProfilesByAccountIdResponse: ...

@typing.type_check_only
class PerformanceReportListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PerformanceReportList: ...

@typing.type_check_only
class PretargetingConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PretargetingConfig: ...

@typing.type_check_only
class PretargetingConfigListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PretargetingConfigList: ...

@typing.type_check_only
class ProductHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Product: ...

@typing.type_check_only
class ProposalHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Proposal: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AmpInspectionResult(typing_extensions.TypedDict, total=False):
    ampIndexStatusVerdict: typing_extensions.Literal[
        "VERDICT_UNSPECIFIED", "PASS", "PARTIAL", "FAIL", "NEUTRAL"
    ]
    ampUrl: str
    indexingState: typing_extensions.Literal[
        "AMP_INDEXING_STATE_UNSPECIFIED",
        "AMP_INDEXING_ALLOWED",
        "BLOCKED_DUE_TO_NOINDEX",
        "BLOCKED_DUE_TO_EXPIRED_UNAVAILABLE_AFTER",
    ]
    issues: _list[AmpIssue]
    lastCrawlTime: str
    pageFetchState: typing_extensions.Literal[
        "PAGE_FETCH_STATE_UNSPECIFIED",
        "SUCCESSFUL",
        "SOFT_404",
        "BLOCKED_ROBOTS_TXT",
        "NOT_FOUND",
        "ACCESS_DENIED",
        "SERVER_ERROR",
        "REDIRECT_ERROR",
        "ACCESS_FORBIDDEN",
        "BLOCKED_4XX",
        "INTERNAL_CRAWL_ERROR",
        "INVALID_URL",
    ]
    robotsTxtState: typing_extensions.Literal[
        "ROBOTS_TXT_STATE_UNSPECIFIED", "ALLOWED", "DISALLOWED"
    ]
    verdict: typing_extensions.Literal[
        "VERDICT_UNSPECIFIED", "PASS", "PARTIAL", "FAIL", "NEUTRAL"
    ]

@typing.type_check_only
class AmpIssue(typing_extensions.TypedDict, total=False):
    issueMessage: str
    severity: typing_extensions.Literal["SEVERITY_UNSPECIFIED", "WARNING", "ERROR"]

@typing.type_check_only
class ApiDataRow(typing_extensions.TypedDict, total=False):
    clicks: float
    ctr: float
    impressions: float
    keys: _list[str]
    position: float

@typing.type_check_only
class ApiDimensionFilter(typing_extensions.TypedDict, total=False):
    dimension: typing_extensions.Literal[
        "QUERY", "PAGE", "COUNTRY", "DEVICE", "SEARCH_APPEARANCE"
    ]
    expression: str
    operator: typing_extensions.Literal[
        "EQUALS",
        "NOT_EQUALS",
        "CONTAINS",
        "NOT_CONTAINS",
        "INCLUDING_REGEX",
        "EXCLUDING_REGEX",
    ]

@typing.type_check_only
class ApiDimensionFilterGroup(typing_extensions.TypedDict, total=False):
    filters: _list[ApiDimensionFilter]
    groupType: typing_extensions.Literal["AND"]

@typing.type_check_only
class BlockedResource(typing_extensions.TypedDict, total=False):
    url: str

@typing.type_check_only
class DetectedItems(typing_extensions.TypedDict, total=False):
    items: _list[Item]
    richResultType: str

@typing.type_check_only
class Image(typing_extensions.TypedDict, total=False):
    data: str
    mimeType: str

@typing.type_check_only
class IndexStatusInspectionResult(typing_extensions.TypedDict, total=False):
    coverageState: str
    crawledAs: typing_extensions.Literal[
        "CRAWLING_USER_AGENT_UNSPECIFIED", "DESKTOP", "MOBILE"
    ]
    googleCanonical: str
    indexingState: typing_extensions.Literal[
        "INDEXING_STATE_UNSPECIFIED",
        "INDEXING_ALLOWED",
        "BLOCKED_BY_META_TAG",
        "BLOCKED_BY_HTTP_HEADER",
        "BLOCKED_BY_ROBOTS_TXT",
    ]
    lastCrawlTime: str
    pageFetchState: typing_extensions.Literal[
        "PAGE_FETCH_STATE_UNSPECIFIED",
        "SUCCESSFUL",
        "SOFT_404",
        "BLOCKED_ROBOTS_TXT",
        "NOT_FOUND",
        "ACCESS_DENIED",
        "SERVER_ERROR",
        "REDIRECT_ERROR",
        "ACCESS_FORBIDDEN",
        "BLOCKED_4XX",
        "INTERNAL_CRAWL_ERROR",
        "INVALID_URL",
    ]
    referringUrls: _list[str]
    robotsTxtState: typing_extensions.Literal[
        "ROBOTS_TXT_STATE_UNSPECIFIED", "ALLOWED", "DISALLOWED"
    ]
    sitemap: _list[str]
    userCanonical: str
    verdict: typing_extensions.Literal[
        "VERDICT_UNSPECIFIED", "PASS", "PARTIAL", "FAIL", "NEUTRAL"
    ]

@typing.type_check_only
class InspectUrlIndexRequest(typing_extensions.TypedDict, total=False):
    inspectionUrl: str
    languageCode: str
    siteUrl: str

@typing.type_check_only
class InspectUrlIndexResponse(typing_extensions.TypedDict, total=False):
    inspectionResult: UrlInspectionResult

@typing.type_check_only
class Item(typing_extensions.TypedDict, total=False):
    issues: _list[RichResultsIssue]
    name: str

@typing.type_check_only
class MobileFriendlyIssue(typing_extensions.TypedDict, total=False):
    rule: typing_extensions.Literal[
        "MOBILE_FRIENDLY_RULE_UNSPECIFIED",
        "USES_INCOMPATIBLE_PLUGINS",
        "CONFIGURE_VIEWPORT",
        "FIXED_WIDTH_VIEWPORT",
        "SIZE_CONTENT_TO_VIEWPORT",
        "USE_LEGIBLE_FONT_SIZES",
        "TAP_TARGETS_TOO_CLOSE",
    ]

@typing.type_check_only
class MobileUsabilityInspectionResult(typing_extensions.TypedDict, total=False):
    issues: _list[MobileUsabilityIssue]
    verdict: typing_extensions.Literal[
        "VERDICT_UNSPECIFIED", "PASS", "PARTIAL", "FAIL", "NEUTRAL"
    ]

@typing.type_check_only
class MobileUsabilityIssue(typing_extensions.TypedDict, total=False):
    issueType: typing_extensions.Literal[
        "MOBILE_USABILITY_ISSUE_TYPE_UNSPECIFIED",
        "USES_INCOMPATIBLE_PLUGINS",
        "CONFIGURE_VIEWPORT",
        "FIXED_WIDTH_VIEWPORT",
        "SIZE_CONTENT_TO_VIEWPORT",
        "USE_LEGIBLE_FONT_SIZES",
        "TAP_TARGETS_TOO_CLOSE",
    ]
    message: str
    severity: typing_extensions.Literal["SEVERITY_UNSPECIFIED", "WARNING", "ERROR"]

@typing.type_check_only
class ResourceIssue(typing_extensions.TypedDict, total=False):
    blockedResource: BlockedResource

@typing.type_check_only
class RichResultsInspectionResult(typing_extensions.TypedDict, total=False):
    detectedItems: _list[DetectedItems]
    verdict: typing_extensions.Literal[
        "VERDICT_UNSPECIFIED", "PASS", "PARTIAL", "FAIL", "NEUTRAL"
    ]

@typing.type_check_only
class RichResultsIssue(typing_extensions.TypedDict, total=False):
    issueMessage: str
    severity: typing_extensions.Literal["SEVERITY_UNSPECIFIED", "WARNING", "ERROR"]

@typing.type_check_only
class RunMobileFriendlyTestRequest(typing_extensions.TypedDict, total=False):
    requestScreenshot: bool
    url: str

@typing.type_check_only
class RunMobileFriendlyTestResponse(typing_extensions.TypedDict, total=False):
    mobileFriendliness: typing_extensions.Literal[
        "MOBILE_FRIENDLY_TEST_RESULT_UNSPECIFIED",
        "MOBILE_FRIENDLY",
        "NOT_MOBILE_FRIENDLY",
    ]
    mobileFriendlyIssues: _list[MobileFriendlyIssue]
    resourceIssues: _list[ResourceIssue]
    screenshot: Image
    testStatus: TestStatus

@typing.type_check_only
class SearchAnalyticsQueryRequest(typing_extensions.TypedDict, total=False):
    aggregationType: typing_extensions.Literal["AUTO", "BY_PROPERTY", "BY_PAGE"]
    dataState: typing_extensions.Literal["DATA_STATE_UNSPECIFIED", "FINAL", "ALL"]
    dimensionFilterGroups: _list[ApiDimensionFilterGroup]
    dimensions: _list[str]
    endDate: str
    rowLimit: int
    searchType: typing_extensions.Literal[
        "WEB", "IMAGE", "VIDEO", "NEWS", "DISCOVER", "GOOGLE_NEWS"
    ]
    startDate: str
    startRow: int
    type: typing_extensions.Literal[
        "WEB", "IMAGE", "VIDEO", "NEWS", "DISCOVER", "GOOGLE_NEWS"
    ]

@typing.type_check_only
class SearchAnalyticsQueryResponse(typing_extensions.TypedDict, total=False):
    responseAggregationType: typing_extensions.Literal["AUTO", "BY_PROPERTY", "BY_PAGE"]
    rows: _list[ApiDataRow]

@typing.type_check_only
class SitemapsListResponse(typing_extensions.TypedDict, total=False):
    sitemap: _list[WmxSitemap]

@typing.type_check_only
class SitesListResponse(typing_extensions.TypedDict, total=False):
    siteEntry: _list[WmxSite]

@typing.type_check_only
class TestStatus(typing_extensions.TypedDict, total=False):
    details: str
    status: typing_extensions.Literal[
        "TEST_STATUS_UNSPECIFIED", "COMPLETE", "INTERNAL_ERROR", "PAGE_UNREACHABLE"
    ]

@typing.type_check_only
class UrlInspectionResult(typing_extensions.TypedDict, total=False):
    ampResult: AmpInspectionResult
    indexStatusResult: IndexStatusInspectionResult
    inspectionResultLink: str
    mobileUsabilityResult: MobileUsabilityInspectionResult
    richResultsResult: RichResultsInspectionResult

@typing.type_check_only
class WmxSite(typing_extensions.TypedDict, total=False):
    permissionLevel: typing_extensions.Literal[
        "SITE_PERMISSION_LEVEL_UNSPECIFIED",
        "SITE_OWNER",
        "SITE_FULL_USER",
        "SITE_RESTRICTED_USER",
        "SITE_UNVERIFIED_USER",
    ]
    siteUrl: str

@typing.type_check_only
class WmxSitemap(typing_extensions.TypedDict, total=False):
    contents: _list[WmxSitemapContent]
    errors: str
    isPending: bool
    isSitemapsIndex: bool
    lastDownloaded: str
    lastSubmitted: str
    path: str
    type: typing_extensions.Literal[
        "NOT_SITEMAP",
        "URL_LIST",
        "SITEMAP",
        "RSS_FEED",
        "ATOM_FEED",
        "PATTERN_SITEMAP",
        "OCEANFRONT",
    ]
    warnings: str

@typing.type_check_only
class WmxSitemapContent(typing_extensions.TypedDict, total=False):
    indexed: str
    submitted: str
    type: typing_extensions.Literal[
        "WEB",
        "IMAGE",
        "VIDEO",
        "NEWS",
        "MOBILE",
        "ANDROID_APP",
        "PATTERN",
        "IOS_APP",
        "DATA_FEED_ELEMENT",
    ]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudChannelV1ActivateEntitlementRequest(
    typing_extensions.TypedDict, total=False
):
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1AdminUser(typing_extensions.TypedDict, total=False):
    email: str
    familyName: str
    givenName: str

@typing.type_check_only
class GoogleCloudChannelV1AssociationInfo(typing_extensions.TypedDict, total=False):
    baseEntitlement: str

@typing.type_check_only
class GoogleCloudChannelV1CancelEntitlementRequest(
    typing_extensions.TypedDict, total=False
):
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1ChangeOfferRequest(typing_extensions.TypedDict, total=False):
    offer: str
    parameters: _list[GoogleCloudChannelV1Parameter]
    purchaseOrderId: str
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1ChangeParametersRequest(
    typing_extensions.TypedDict, total=False
):
    parameters: _list[GoogleCloudChannelV1Parameter]
    purchaseOrderId: str
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1ChangeRenewalSettingsRequest(
    typing_extensions.TypedDict, total=False
):
    renewalSettings: GoogleCloudChannelV1RenewalSettings
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1ChannelPartnerLink(typing_extensions.TypedDict, total=False):
    channelPartnerCloudIdentityInfo: GoogleCloudChannelV1CloudIdentityInfo
    createTime: str
    inviteLinkUri: str
    linkState: typing_extensions.Literal[
        "CHANNEL_PARTNER_LINK_STATE_UNSPECIFIED",
        "INVITED",
        "ACTIVE",
        "REVOKED",
        "SUSPENDED",
    ]
    name: str
    publicId: str
    resellerCloudIdentityId: str
    updateTime: str

@typing.type_check_only
class GoogleCloudChannelV1ChannelPartnerRepricingConfig(
    typing_extensions.TypedDict, total=False
):
    name: str
    repricingConfig: GoogleCloudChannelV1RepricingConfig
    updateTime: str

@typing.type_check_only
class GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest(
    typing_extensions.TypedDict, total=False
):
    domain: str

@typing.type_check_only
class GoogleCloudChannelV1CheckCloudIdentityAccountsExistResponse(
    typing_extensions.TypedDict, total=False
):
    cloudIdentityAccounts: _list[GoogleCloudChannelV1CloudIdentityCustomerAccount]

@typing.type_check_only
class GoogleCloudChannelV1CloudIdentityCustomerAccount(
    typing_extensions.TypedDict, total=False
):
    customerCloudIdentityId: str
    customerName: str
    existing: bool
    owned: bool

@typing.type_check_only
class GoogleCloudChannelV1CloudIdentityInfo(typing_extensions.TypedDict, total=False):
    adminConsoleUri: str
    alternateEmail: str
    customerType: typing_extensions.Literal[
        "CUSTOMER_TYPE_UNSPECIFIED", "DOMAIN", "TEAM"
    ]
    eduData: GoogleCloudChannelV1EduData
    isDomainVerified: bool
    languageCode: str
    phoneNumber: str
    primaryDomain: str

@typing.type_check_only
class GoogleCloudChannelV1CommitmentSettings(typing_extensions.TypedDict, total=False):
    endTime: str
    renewalSettings: GoogleCloudChannelV1RenewalSettings
    startTime: str

@typing.type_check_only
class GoogleCloudChannelV1Constraints(typing_extensions.TypedDict, total=False):
    customerConstraints: GoogleCloudChannelV1CustomerConstraints

@typing.type_check_only
class GoogleCloudChannelV1ContactInfo(typing_extensions.TypedDict, total=False):
    displayName: str
    email: str
    firstName: str
    lastName: str
    phone: str
    title: str

@typing.type_check_only
class GoogleCloudChannelV1CreateEntitlementRequest(
    typing_extensions.TypedDict, total=False
):
    entitlement: GoogleCloudChannelV1Entitlement
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1Customer(typing_extensions.TypedDict, total=False):
    alternateEmail: str
    channelPartnerId: str
    cloudIdentityId: str
    cloudIdentityInfo: GoogleCloudChannelV1CloudIdentityInfo
    createTime: str
    domain: str
    languageCode: str
    name: str
    orgDisplayName: str
    orgPostalAddress: GoogleTypePostalAddress
    primaryContactInfo: GoogleCloudChannelV1ContactInfo
    updateTime: str

@typing.type_check_only
class GoogleCloudChannelV1CustomerConstraints(typing_extensions.TypedDict, total=False):
    allowedCustomerTypes: _list[str]
    allowedRegions: _list[str]
    promotionalOrderTypes: _list[str]

@typing.type_check_only
class GoogleCloudChannelV1CustomerEvent(typing_extensions.TypedDict, total=False):
    customer: str
    eventType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "PRIMARY_DOMAIN_CHANGED", "PRIMARY_DOMAIN_VERIFIED"
    ]

@typing.type_check_only
class GoogleCloudChannelV1CustomerRepricingConfig(
    typing_extensions.TypedDict, total=False
):
    name: str
    repricingConfig: GoogleCloudChannelV1RepricingConfig
    updateTime: str

@typing.type_check_only
class GoogleCloudChannelV1EduData(typing_extensions.TypedDict, total=False):
    instituteSize: typing_extensions.Literal[
        "INSTITUTE_SIZE_UNSPECIFIED",
        "SIZE_1_100",
        "SIZE_101_500",
        "SIZE_501_1000",
        "SIZE_1001_2000",
        "SIZE_2001_5000",
        "SIZE_5001_10000",
        "SIZE_10001_OR_MORE",
    ]
    instituteType: typing_extensions.Literal[
        "INSTITUTE_TYPE_UNSPECIFIED", "K12", "UNIVERSITY"
    ]
    website: str

@typing.type_check_only
class GoogleCloudChannelV1Entitlement(typing_extensions.TypedDict, total=False):
    associationInfo: GoogleCloudChannelV1AssociationInfo
    commitmentSettings: GoogleCloudChannelV1CommitmentSettings
    createTime: str
    name: str
    offer: str
    parameters: _list[GoogleCloudChannelV1Parameter]
    provisionedService: GoogleCloudChannelV1ProvisionedService
    provisioningState: typing_extensions.Literal[
        "PROVISIONING_STATE_UNSPECIFIED", "ACTIVE", "SUSPENDED"
    ]
    purchaseOrderId: str
    suspensionReasons: _list[str]
    trialSettings: GoogleCloudChannelV1TrialSettings
    updateTime: str

@typing.type_check_only
class GoogleCloudChannelV1EntitlementEvent(typing_extensions.TypedDict, total=False):
    entitlement: str
    eventType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "CREATED",
        "PRICE_PLAN_SWITCHED",
        "COMMITMENT_CHANGED",
        "RENEWED",
        "SUSPENDED",
        "ACTIVATED",
        "CANCELLED",
        "SKU_CHANGED",
        "RENEWAL_SETTING_CHANGED",
        "PAID_SERVICE_STARTED",
        "LICENSE_ASSIGNMENT_CHANGED",
        "LICENSE_CAP_CHANGED",
    ]

@typing.type_check_only
class GoogleCloudChannelV1ImportCustomerRequest(
    typing_extensions.TypedDict, total=False
):
    authToken: str
    channelPartnerId: str
    cloudIdentityId: str
    customer: str
    domain: str
    overwriteIfExists: bool

@typing.type_check_only
class GoogleCloudChannelV1ListChannelPartnerLinksResponse(
    typing_extensions.TypedDict, total=False
):
    channelPartnerLinks: _list[GoogleCloudChannelV1ChannelPartnerLink]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    channelPartnerRepricingConfigs: _list[
        GoogleCloudChannelV1ChannelPartnerRepricingConfig
    ]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudChannelV1ListCustomerRepricingConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    customerRepricingConfigs: _list[GoogleCloudChannelV1CustomerRepricingConfig]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudChannelV1ListCustomersResponse(
    typing_extensions.TypedDict, total=False
):
    customers: _list[GoogleCloudChannelV1Customer]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudChannelV1ListEntitlementsResponse(
    typing_extensions.TypedDict, total=False
):
    entitlements: _list[GoogleCloudChannelV1Entitlement]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudChannelV1ListOffersResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    offers: _list[GoogleCloudChannelV1Offer]

@typing.type_check_only
class GoogleCloudChannelV1ListProductsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    products: _list[GoogleCloudChannelV1Product]

@typing.type_check_only
class GoogleCloudChannelV1ListPurchasableOffersResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    purchasableOffers: _list[GoogleCloudChannelV1PurchasableOffer]

@typing.type_check_only
class GoogleCloudChannelV1ListPurchasableSkusResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    purchasableSkus: _list[GoogleCloudChannelV1PurchasableSku]

@typing.type_check_only
class GoogleCloudChannelV1ListSkusResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    skus: _list[GoogleCloudChannelV1Sku]

@typing.type_check_only
class GoogleCloudChannelV1ListSubscribersResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    serviceAccounts: _list[str]
    topic: str

@typing.type_check_only
class GoogleCloudChannelV1ListTransferableOffersRequest(
    typing_extensions.TypedDict, total=False
):
    cloudIdentityId: str
    customerName: str
    languageCode: str
    pageSize: int
    pageToken: str
    sku: str

@typing.type_check_only
class GoogleCloudChannelV1ListTransferableOffersResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    transferableOffers: _list[GoogleCloudChannelV1TransferableOffer]

@typing.type_check_only
class GoogleCloudChannelV1ListTransferableSkusRequest(
    typing_extensions.TypedDict, total=False
):
    authToken: str
    cloudIdentityId: str
    customerName: str
    languageCode: str
    pageSize: int
    pageToken: str

@typing.type_check_only
class GoogleCloudChannelV1ListTransferableSkusResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    transferableSkus: _list[GoogleCloudChannelV1TransferableSku]

@typing.type_check_only
class GoogleCloudChannelV1MarketingInfo(typing_extensions.TypedDict, total=False):
    defaultLogo: GoogleCloudChannelV1Media
    description: str
    displayName: str

@typing.type_check_only
class GoogleCloudChannelV1Media(typing_extensions.TypedDict, total=False):
    content: str
    title: str
    type: typing_extensions.Literal["MEDIA_TYPE_UNSPECIFIED", "MEDIA_TYPE_IMAGE"]

@typing.type_check_only
class GoogleCloudChannelV1Offer(typing_extensions.TypedDict, total=False):
    constraints: GoogleCloudChannelV1Constraints
    endTime: str
    marketingInfo: GoogleCloudChannelV1MarketingInfo
    name: str
    parameterDefinitions: _list[GoogleCloudChannelV1ParameterDefinition]
    plan: GoogleCloudChannelV1Plan
    priceByResources: _list[GoogleCloudChannelV1PriceByResource]
    sku: GoogleCloudChannelV1Sku
    startTime: str

@typing.type_check_only
class GoogleCloudChannelV1OperationMetadata(typing_extensions.TypedDict, total=False):
    operationType: typing_extensions.Literal[
        "OPERATION_TYPE_UNSPECIFIED",
        "CREATE_ENTITLEMENT",
        "CHANGE_RENEWAL_SETTINGS",
        "START_PAID_SERVICE",
        "ACTIVATE_ENTITLEMENT",
        "SUSPEND_ENTITLEMENT",
        "CANCEL_ENTITLEMENT",
        "TRANSFER_ENTITLEMENTS",
        "TRANSFER_ENTITLEMENTS_TO_GOOGLE",
        "CHANGE_OFFER",
        "CHANGE_PARAMETERS",
        "PROVISION_CLOUD_IDENTITY",
    ]

@typing.type_check_only
class GoogleCloudChannelV1Parameter(typing_extensions.TypedDict, total=False):
    editable: bool
    name: str
    value: GoogleCloudChannelV1Value

@typing.type_check_only
class GoogleCloudChannelV1ParameterDefinition(typing_extensions.TypedDict, total=False):
    allowedValues: _list[GoogleCloudChannelV1Value]
    maxValue: GoogleCloudChannelV1Value
    minValue: GoogleCloudChannelV1Value
    name: str
    optional: bool
    parameterType: typing_extensions.Literal[
        "PARAMETER_TYPE_UNSPECIFIED", "INT64", "STRING", "DOUBLE"
    ]

@typing.type_check_only
class GoogleCloudChannelV1PercentageAdjustment(
    typing_extensions.TypedDict, total=False
):
    percentage: GoogleTypeDecimal

@typing.type_check_only
class GoogleCloudChannelV1Period(typing_extensions.TypedDict, total=False):
    duration: int
    periodType: typing_extensions.Literal[
        "PERIOD_TYPE_UNSPECIFIED", "DAY", "MONTH", "YEAR"
    ]

@typing.type_check_only
class GoogleCloudChannelV1Plan(typing_extensions.TypedDict, total=False):
    billingAccount: str
    paymentCycle: GoogleCloudChannelV1Period
    paymentPlan: typing_extensions.Literal[
        "PAYMENT_PLAN_UNSPECIFIED", "COMMITMENT", "FLEXIBLE", "FREE", "TRIAL", "OFFLINE"
    ]
    paymentType: typing_extensions.Literal[
        "PAYMENT_TYPE_UNSPECIFIED", "PREPAY", "POSTPAY"
    ]
    trialPeriod: GoogleCloudChannelV1Period

@typing.type_check_only
class GoogleCloudChannelV1Price(typing_extensions.TypedDict, total=False):
    basePrice: GoogleTypeMoney
    discount: float
    effectivePrice: GoogleTypeMoney
    externalPriceUri: str

@typing.type_check_only
class GoogleCloudChannelV1PriceByResource(typing_extensions.TypedDict, total=False):
    price: GoogleCloudChannelV1Price
    pricePhases: _list[GoogleCloudChannelV1PricePhase]
    resourceType: typing_extensions.Literal[
        "RESOURCE_TYPE_UNSPECIFIED",
        "SEAT",
        "MAU",
        "GB",
        "LICENSED_USER",
        "MINUTES",
        "IAAS_USAGE",
        "SUBSCRIPTION",
    ]

@typing.type_check_only
class GoogleCloudChannelV1PricePhase(typing_extensions.TypedDict, total=False):
    firstPeriod: int
    lastPeriod: int
    periodType: typing_extensions.Literal[
        "PERIOD_TYPE_UNSPECIFIED", "DAY", "MONTH", "YEAR"
    ]
    price: GoogleCloudChannelV1Price
    priceTiers: _list[GoogleCloudChannelV1PriceTier]

@typing.type_check_only
class GoogleCloudChannelV1PriceTier(typing_extensions.TypedDict, total=False):
    firstResource: int
    lastResource: int
    price: GoogleCloudChannelV1Price

@typing.type_check_only
class GoogleCloudChannelV1Product(typing_extensions.TypedDict, total=False):
    marketingInfo: GoogleCloudChannelV1MarketingInfo
    name: str

@typing.type_check_only
class GoogleCloudChannelV1ProvisionCloudIdentityRequest(
    typing_extensions.TypedDict, total=False
):
    cloudIdentityInfo: GoogleCloudChannelV1CloudIdentityInfo
    user: GoogleCloudChannelV1AdminUser
    validateOnly: bool

@typing.type_check_only
class GoogleCloudChannelV1ProvisionedService(typing_extensions.TypedDict, total=False):
    productId: str
    provisioningId: str
    skuId: str

@typing.type_check_only
class GoogleCloudChannelV1PurchasableOffer(typing_extensions.TypedDict, total=False):
    offer: GoogleCloudChannelV1Offer

@typing.type_check_only
class GoogleCloudChannelV1PurchasableSku(typing_extensions.TypedDict, total=False):
    sku: GoogleCloudChannelV1Sku

@typing.type_check_only
class GoogleCloudChannelV1RegisterSubscriberRequest(
    typing_extensions.TypedDict, total=False
):
    serviceAccount: str

@typing.type_check_only
class GoogleCloudChannelV1RegisterSubscriberResponse(
    typing_extensions.TypedDict, total=False
):
    topic: str

@typing.type_check_only
class GoogleCloudChannelV1RenewalSettings(typing_extensions.TypedDict, total=False):
    enableRenewal: bool
    paymentCycle: GoogleCloudChannelV1Period
    paymentPlan: typing_extensions.Literal[
        "PAYMENT_PLAN_UNSPECIFIED", "COMMITMENT", "FLEXIBLE", "FREE", "TRIAL", "OFFLINE"
    ]
    resizeUnitCount: bool

@typing.type_check_only
class GoogleCloudChannelV1RepricingAdjustment(typing_extensions.TypedDict, total=False):
    percentageAdjustment: GoogleCloudChannelV1PercentageAdjustment

@typing.type_check_only
class GoogleCloudChannelV1RepricingConfig(typing_extensions.TypedDict, total=False):
    adjustment: GoogleCloudChannelV1RepricingAdjustment
    channelPartnerGranularity: GoogleCloudChannelV1RepricingConfigChannelPartnerGranularity
    effectiveInvoiceMonth: GoogleTypeDate
    entitlementGranularity: GoogleCloudChannelV1RepricingConfigEntitlementGranularity
    rebillingBasis: typing_extensions.Literal[
        "REBILLING_BASIS_UNSPECIFIED", "COST_AT_LIST", "DIRECT_CUSTOMER_COST"
    ]

@typing.type_check_only
class GoogleCloudChannelV1RepricingConfigChannelPartnerGranularity(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudChannelV1RepricingConfigEntitlementGranularity(
    typing_extensions.TypedDict, total=False
):
    entitlement: str

@typing.type_check_only
class GoogleCloudChannelV1Sku(typing_extensions.TypedDict, total=False):
    marketingInfo: GoogleCloudChannelV1MarketingInfo
    name: str
    product: GoogleCloudChannelV1Product

@typing.type_check_only
class GoogleCloudChannelV1StartPaidServiceRequest(
    typing_extensions.TypedDict, total=False
):
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1SubscriberEvent(typing_extensions.TypedDict, total=False):
    customerEvent: GoogleCloudChannelV1CustomerEvent
    entitlementEvent: GoogleCloudChannelV1EntitlementEvent

@typing.type_check_only
class GoogleCloudChannelV1SuspendEntitlementRequest(
    typing_extensions.TypedDict, total=False
):
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1TransferEligibility(typing_extensions.TypedDict, total=False):
    description: str
    ineligibilityReason: typing_extensions.Literal[
        "REASON_UNSPECIFIED",
        "PENDING_TOS_ACCEPTANCE",
        "SKU_NOT_ELIGIBLE",
        "SKU_SUSPENDED",
    ]
    isEligible: bool

@typing.type_check_only
class GoogleCloudChannelV1TransferEntitlementsRequest(
    typing_extensions.TypedDict, total=False
):
    authToken: str
    entitlements: _list[GoogleCloudChannelV1Entitlement]
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1TransferEntitlementsResponse(
    typing_extensions.TypedDict, total=False
):
    entitlements: _list[GoogleCloudChannelV1Entitlement]

@typing.type_check_only
class GoogleCloudChannelV1TransferEntitlementsToGoogleRequest(
    typing_extensions.TypedDict, total=False
):
    entitlements: _list[GoogleCloudChannelV1Entitlement]
    requestId: str

@typing.type_check_only
class GoogleCloudChannelV1TransferableOffer(typing_extensions.TypedDict, total=False):
    offer: GoogleCloudChannelV1Offer

@typing.type_check_only
class GoogleCloudChannelV1TransferableSku(typing_extensions.TypedDict, total=False):
    legacySku: GoogleCloudChannelV1Sku
    sku: GoogleCloudChannelV1Sku
    transferEligibility: GoogleCloudChannelV1TransferEligibility

@typing.type_check_only
class GoogleCloudChannelV1TrialSettings(typing_extensions.TypedDict, total=False):
    endTime: str
    trial: bool

@typing.type_check_only
class GoogleCloudChannelV1UnregisterSubscriberRequest(
    typing_extensions.TypedDict, total=False
):
    serviceAccount: str

@typing.type_check_only
class GoogleCloudChannelV1UnregisterSubscriberResponse(
    typing_extensions.TypedDict, total=False
):
    topic: str

@typing.type_check_only
class GoogleCloudChannelV1UpdateChannelPartnerLinkRequest(
    typing_extensions.TypedDict, total=False
):
    channelPartnerLink: GoogleCloudChannelV1ChannelPartnerLink
    updateMask: str

@typing.type_check_only
class GoogleCloudChannelV1Value(typing_extensions.TypedDict, total=False):
    boolValue: bool
    doubleValue: float
    int64Value: str
    protoValue: dict[str, typing.Any]
    stringValue: str

@typing.type_check_only
class GoogleCloudChannelV1alpha1AssociationInfo(
    typing_extensions.TypedDict, total=False
):
    baseEntitlement: str

@typing.type_check_only
class GoogleCloudChannelV1alpha1ChannelPartnerEvent(
    typing_extensions.TypedDict, total=False
):
    channelPartner: str
    eventType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "LINK_STATE_CHANGED", "PARTNER_ADVANTAGE_INFO_CHANGED"
    ]

@typing.type_check_only
class GoogleCloudChannelV1alpha1CommitmentSettings(
    typing_extensions.TypedDict, total=False
):
    endTime: str
    renewalSettings: GoogleCloudChannelV1alpha1RenewalSettings
    startTime: str

@typing.type_check_only
class GoogleCloudChannelV1alpha1CustomerEvent(typing_extensions.TypedDict, total=False):
    customer: str
    eventType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "PRIMARY_DOMAIN_CHANGED", "PRIMARY_DOMAIN_VERIFIED"
    ]

@typing.type_check_only
class GoogleCloudChannelV1alpha1Entitlement(typing_extensions.TypedDict, total=False):
    assignedUnits: int
    associationInfo: GoogleCloudChannelV1alpha1AssociationInfo
    channelPartnerId: str
    commitmentSettings: GoogleCloudChannelV1alpha1CommitmentSettings
    createTime: str
    maxUnits: int
    name: str
    numUnits: int
    offer: str
    parameters: _list[GoogleCloudChannelV1alpha1Parameter]
    provisionedService: GoogleCloudChannelV1alpha1ProvisionedService
    provisioningState: typing_extensions.Literal[
        "PROVISIONING_STATE_UNSPECIFIED",
        "ACTIVE",
        "CANCELED",
        "COMPLETE",
        "PENDING",
        "SUSPENDED",
    ]
    purchaseOrderId: str
    suspensionReasons: _list[str]
    trialSettings: GoogleCloudChannelV1alpha1TrialSettings
    updateTime: str

@typing.type_check_only
class GoogleCloudChannelV1alpha1EntitlementEvent(
    typing_extensions.TypedDict, total=False
):
    entitlement: str
    eventType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "CREATED",
        "PRICE_PLAN_SWITCHED",
        "COMMITMENT_CHANGED",
        "RENEWED",
        "SUSPENDED",
        "ACTIVATED",
        "CANCELLED",
        "SKU_CHANGED",
        "RENEWAL_SETTING_CHANGED",
        "PAID_SERVICE_STARTED",
        "LICENSE_ASSIGNMENT_CHANGED",
        "LICENSE_CAP_CHANGED",
    ]

@typing.type_check_only
class GoogleCloudChannelV1alpha1OperationMetadata(
    typing_extensions.TypedDict, total=False
):
    operationType: typing_extensions.Literal[
        "OPERATION_TYPE_UNSPECIFIED",
        "CREATE_ENTITLEMENT",
        "CHANGE_QUANTITY",
        "CHANGE_RENEWAL_SETTINGS",
        "CHANGE_PLAN",
        "START_PAID_SERVICE",
        "CHANGE_SKU",
        "ACTIVATE_ENTITLEMENT",
        "SUSPEND_ENTITLEMENT",
        "CANCEL_ENTITLEMENT",
        "TRANSFER_ENTITLEMENTS",
        "TRANSFER_ENTITLEMENTS_TO_GOOGLE",
        "CHANGE_OFFER",
        "CHANGE_PARAMETERS",
        "PROVISION_CLOUD_IDENTITY",
    ]

@typing.type_check_only
class GoogleCloudChannelV1alpha1Parameter(typing_extensions.TypedDict, total=False):
    editable: bool
    name: str
    value: GoogleCloudChannelV1alpha1Value

@typing.type_check_only
class GoogleCloudChannelV1alpha1Period(typing_extensions.TypedDict, total=False):
    duration: int
    periodType: typing_extensions.Literal[
        "PERIOD_TYPE_UNSPECIFIED", "DAY", "MONTH", "YEAR"
    ]

@typing.type_check_only
class GoogleCloudChannelV1alpha1ProvisionedService(
    typing_extensions.TypedDict, total=False
):
    productId: str
    provisioningId: str
    skuId: str

@typing.type_check_only
class GoogleCloudChannelV1alpha1RenewalSettings(
    typing_extensions.TypedDict, total=False
):
    disableCommitment: bool
    enableRenewal: bool
    paymentCycle: GoogleCloudChannelV1alpha1Period
    paymentOption: typing_extensions.Literal[
        "PAYMENT_OPTION_UNSPECIFIED", "ANNUAL", "MONTHLY"
    ]
    paymentPlan: typing_extensions.Literal[
        "PAYMENT_PLAN_UNSPECIFIED", "COMMITMENT", "FLEXIBLE", "FREE", "TRIAL", "OFFLINE"
    ]
    resizeUnitCount: bool

@typing.type_check_only
class GoogleCloudChannelV1alpha1SubscriberEvent(
    typing_extensions.TypedDict, total=False
):
    channelPartnerEvent: GoogleCloudChannelV1alpha1ChannelPartnerEvent
    customerEvent: GoogleCloudChannelV1alpha1CustomerEvent
    entitlementEvent: GoogleCloudChannelV1alpha1EntitlementEvent

@typing.type_check_only
class GoogleCloudChannelV1alpha1TransferEntitlementsResponse(
    typing_extensions.TypedDict, total=False
):
    entitlements: _list[GoogleCloudChannelV1alpha1Entitlement]

@typing.type_check_only
class GoogleCloudChannelV1alpha1TrialSettings(typing_extensions.TypedDict, total=False):
    endTime: str
    trial: bool

@typing.type_check_only
class GoogleCloudChannelV1alpha1Value(typing_extensions.TypedDict, total=False):
    boolValue: bool
    doubleValue: float
    int64Value: str
    protoValue: dict[str, typing.Any]
    stringValue: str

@typing.type_check_only
class GoogleLongrunningCancelOperationRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[GoogleLongrunningOperation]

@typing.type_check_only
class GoogleLongrunningOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class GoogleTypeDate(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class GoogleTypeDecimal(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class GoogleTypeMoney(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str

@typing.type_check_only
class GoogleTypePostalAddress(typing_extensions.TypedDict, total=False):
    addressLines: _list[str]
    administrativeArea: str
    languageCode: str
    locality: str
    organization: str
    postalCode: str
    recipients: _list[str]
    regionCode: str
    revision: int
    sortingCode: str
    sublocality: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class FitnessResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DataSourcesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DataPointChangesResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    userId: str,
                    dataSourceId: str,
                    limit: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListDataPointChangesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListDataPointChangesResponseHttpRequest,
                    previous_response: ListDataPointChangesResponse,
                ) -> ListDataPointChangesResponseHttpRequest | None: ...

            @typing.type_check_only
            class DatasetsResource(googleapiclient.discovery.Resource):
                def delete(
                    self,
                    *,
                    userId: str,
                    dataSourceId: str,
                    datasetId: str,
                    **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self,
                    *,
                    userId: str,
                    dataSourceId: str,
                    datasetId: str,
                    limit: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> DatasetHttpRequest: ...
                def get_next(
                    self,
                    previous_request: DatasetHttpRequest,
                    previous_response: Dataset,
                ) -> DatasetHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    userId: str,
                    dataSourceId: str,
                    datasetId: str,
                    body: Dataset = ...,
                    **kwargs: typing.Any
                ) -> DatasetHttpRequest: ...
                def patch_next(
                    self,
                    previous_request: DatasetHttpRequest,
                    previous_response: Dataset,
                ) -> DatasetHttpRequest | None: ...

            def create(
                self, *, userId: str, body: DataSource = ..., **kwargs: typing.Any
            ) -> DataSourceHttpRequest: ...
            def delete(
                self, *, userId: str, dataSourceId: str, **kwargs: typing.Any
            ) -> DataSourceHttpRequest: ...
            def get(
                self, *, userId: str, dataSourceId: str, **kwargs: typing.Any
            ) -> DataSourceHttpRequest: ...
            def list(
                self,
                *,
                userId: str,
                dataTypeName: str | _list[str] = ...,
                **kwargs: typing.Any
            ) -> ListDataSourcesResponseHttpRequest: ...
            def update(
                self,
                *,
                userId: str,
                dataSourceId: str,
                body: DataSource = ...,
                **kwargs: typing.Any
            ) -> DataSourceHttpRequest: ...
            def dataPointChanges(self) -> DataPointChangesResource: ...
            def datasets(self) -> DatasetsResource: ...

        @typing.type_check_only
        class DatasetResource(googleapiclient.discovery.Resource):
            def aggregate(
                self, *, userId: str, body: AggregateRequest = ..., **kwargs: typing.Any
            ) -> AggregateResponseHttpRequest: ...

        @typing.type_check_only
        class SessionsResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, userId: str, sessionId: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def list(
                self,
                *,
                userId: str,
                activityType: int | _list[int] = ...,
                endTime: str = ...,
                includeDeleted: bool = ...,
                pageToken: str = ...,
                startTime: str = ...,
                **kwargs: typing.Any
            ) -> ListSessionsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListSessionsResponseHttpRequest,
                previous_response: ListSessionsResponse,
            ) -> ListSessionsResponseHttpRequest | None: ...
            def update(
                self,
                *,
                userId: str,
                sessionId: str,
                body: Session = ...,
                **kwargs: typing.Any
            ) -> SessionHttpRequest: ...

        def dataSources(self) -> DataSourcesResource: ...
        def dataset(self) -> DatasetResource: ...
        def sessions(self) -> SessionsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def users(self) -> UsersResource: ...

@typing.type_check_only
class AggregateResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AggregateResponse: ...

@typing.type_check_only
class DataSourceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DataSource: ...

@typing.type_check_only
class DatasetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Dataset: ...

@typing.type_check_only
class ListDataPointChangesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDataPointChangesResponse: ...

@typing.type_check_only
class ListDataSourcesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDataSourcesResponse: ...

@typing.type_check_only
class ListSessionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSessionsResponse: ...

@typing.type_check_only
class SessionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Session: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AnalyticsDataResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class PropertiesResource(googleapiclient.discovery.Resource):
        def getMetadata(
            self, *, name: str, **kwargs: typing.Any
        ) -> MetadataHttpRequest: ...
        def runRealtimeReport(
            self,
            *,
            property: str,
            body: RunRealtimeReportRequest = ...,
            **kwargs: typing.Any
        ) -> RunRealtimeReportResponseHttpRequest: ...

    @typing.type_check_only
    class V1alphaResource(googleapiclient.discovery.Resource):
        def batchRunPivotReports(
            self, *, body: BatchRunPivotReportsRequest = ..., **kwargs: typing.Any
        ) -> BatchRunPivotReportsResponseHttpRequest: ...
        def batchRunReports(
            self, *, body: BatchRunReportsRequest = ..., **kwargs: typing.Any
        ) -> BatchRunReportsResponseHttpRequest: ...
        def runPivotReport(
            self, *, body: RunPivotReportRequest = ..., **kwargs: typing.Any
        ) -> RunPivotReportResponseHttpRequest: ...
        def runReport(
            self, *, body: RunReportRequest = ..., **kwargs: typing.Any
        ) -> RunReportResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def properties(self) -> PropertiesResource: ...
    def v1alpha(self) -> V1alphaResource: ...

@typing.type_check_only
class BatchRunPivotReportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchRunPivotReportsResponse: ...

@typing.type_check_only
class BatchRunReportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchRunReportsResponse: ...

@typing.type_check_only
class MetadataHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Metadata: ...

@typing.type_check_only
class RunPivotReportResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RunPivotReportResponse: ...

@typing.type_check_only
class RunRealtimeReportResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RunRealtimeReportResponse: ...

@typing.type_check_only
class RunReportResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RunReportResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AcceleratorType(typing_extensions.TypedDict, total=False):
    name: str
    type: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ListAcceleratorTypesResponse(typing_extensions.TypedDict, total=False):
    acceleratorTypes: _list[AcceleratorType]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListNodesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    nodes: _list[Node]
    unreachable: _list[str]

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListTensorFlowVersionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    tensorflowVersions: _list[TensorFlowVersion]
    unreachable: _list[str]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class NetworkEndpoint(typing_extensions.TypedDict, total=False):
    ipAddress: str
    port: int

@typing.type_check_only
class Node(typing_extensions.TypedDict, total=False):
    acceleratorType: str
    apiVersion: typing_extensions.Literal[
        "API_VERSION_UNSPECIFIED", "V1_ALPHA1", "V1", "V2_ALPHA1"
    ]
    cidrBlock: str
    createTime: str
    description: str
    health: typing_extensions.Literal[
        "HEALTH_UNSPECIFIED",
        "HEALTHY",
        "DEPRECATED_UNHEALTHY",
        "TIMEOUT",
        "UNHEALTHY_TENSORFLOW",
        "UNHEALTHY_MAINTENANCE",
    ]
    healthDescription: str
    ipAddress: str
    labels: dict[str, typing.Any]
    name: str
    network: str
    networkEndpoints: _list[NetworkEndpoint]
    port: str
    schedulingConfig: SchedulingConfig
    serviceAccount: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "CREATING",
        "READY",
        "RESTARTING",
        "REIMAGING",
        "DELETING",
        "REPAIRING",
        "STOPPED",
        "STOPPING",
        "STARTING",
        "PREEMPTED",
        "TERMINATED",
        "HIDING",
        "HIDDEN",
        "UNHIDING",
    ]
    symptoms: _list[Symptom]
    tensorflowVersion: str
    useServiceNetworking: bool

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    cancelRequested: bool
    createTime: str
    endTime: str
    statusDetail: str
    target: str
    verb: str

@typing.type_check_only
class ReimageNodeRequest(typing_extensions.TypedDict, total=False):
    tensorflowVersion: str

@typing.type_check_only
class SchedulingConfig(typing_extensions.TypedDict, total=False):
    preemptible: bool
    reserved: bool

@typing.type_check_only
class StartNodeRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class StopNodeRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Symptom(typing_extensions.TypedDict, total=False):
    createTime: str
    details: str
    symptomType: typing_extensions.Literal[
        "SYMPTOM_TYPE_UNSPECIFIED",
        "LOW_MEMORY",
        "OUT_OF_MEMORY",
        "EXECUTE_TIMED_OUT",
        "MESH_BUILD_FAIL",
        "HBM_OUT_OF_MEMORY",
        "PROJECT_ABUSE",
    ]
    workerId: str

@typing.type_check_only
class TensorFlowVersion(typing_extensions.TypedDict, total=False):
    name: str
    version: str



import abc

from _typeshed import Incomplete

class Cache(metaclass=abc.ABCMeta):
    __metaclass__: Incomplete
    @abc.abstractmethod
    def get(self, url): ...
    @abc.abstractmethod
    def set(self, url, content): ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class GamesResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AchievementDefinitionsResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> AchievementDefinitionsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: AchievementDefinitionsListResponseHttpRequest,
            previous_response: AchievementDefinitionsListResponse,
        ) -> AchievementDefinitionsListResponseHttpRequest | None: ...

    @typing.type_check_only
    class AchievementsResource(googleapiclient.discovery.Resource):
        def increment(
            self,
            *,
            achievementId: str,
            stepsToIncrement: int,
            requestId: str = ...,
            **kwargs: typing.Any
        ) -> AchievementIncrementResponseHttpRequest: ...
        def list(
            self,
            *,
            playerId: str,
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            state: typing_extensions.Literal[
                "ALL", "HIDDEN", "REVEALED", "UNLOCKED"
            ] = ...,
            **kwargs: typing.Any
        ) -> PlayerAchievementListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: PlayerAchievementListResponseHttpRequest,
            previous_response: PlayerAchievementListResponse,
        ) -> PlayerAchievementListResponseHttpRequest | None: ...
        def reveal(
            self, *, achievementId: str, **kwargs: typing.Any
        ) -> AchievementRevealResponseHttpRequest: ...
        def setStepsAtLeast(
            self, *, achievementId: str, steps: int, **kwargs: typing.Any
        ) -> AchievementSetStepsAtLeastResponseHttpRequest: ...
        def unlock(
            self, *, achievementId: str, **kwargs: typing.Any
        ) -> AchievementUnlockResponseHttpRequest: ...
        def updateMultiple(
            self, *, body: AchievementUpdateMultipleRequest = ..., **kwargs: typing.Any
        ) -> AchievementUpdateMultipleResponseHttpRequest: ...

    @typing.type_check_only
    class ApplicationsResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            applicationId: str,
            language: str = ...,
            platformType: typing_extensions.Literal[
                "PLATFORM_TYPE_UNSPECIFIED", "ANDROID", "IOS", "WEB_APP"
            ] = ...,
            **kwargs: typing.Any
        ) -> ApplicationHttpRequest: ...
        def getEndPoint(
            self,
            *,
            applicationId: str = ...,
            endPointType: typing_extensions.Literal[
                "END_POINT_TYPE_UNSPECIFIED", "PROFILE_CREATION", "PROFILE_SETTINGS"
            ] = ...,
            **kwargs: typing.Any
        ) -> EndPointHttpRequest: ...
        def played(self, **kwargs: typing.Any) -> googleapiclient.http.HttpRequest: ...
        def verify(
            self, *, applicationId: str, **kwargs: typing.Any
        ) -> ApplicationVerifyResponseHttpRequest: ...

    @typing.type_check_only
    class EventsResource(googleapiclient.discovery.Resource):
        def listByPlayer(
            self,
            *,
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> PlayerEventListResponseHttpRequest: ...
        def listByPlayer_next(
            self,
            previous_request: PlayerEventListResponseHttpRequest,
            previous_response: PlayerEventListResponse,
        ) -> PlayerEventListResponseHttpRequest | None: ...
        def listDefinitions(
            self,
            *,
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> EventDefinitionListResponseHttpRequest: ...
        def listDefinitions_next(
            self,
            previous_request: EventDefinitionListResponseHttpRequest,
            previous_response: EventDefinitionListResponse,
        ) -> EventDefinitionListResponseHttpRequest | None: ...
        def record(
            self,
            *,
            body: EventRecordRequest = ...,
            language: str = ...,
            **kwargs: typing.Any
        ) -> EventUpdateResponseHttpRequest: ...

    @typing.type_check_only
    class LeaderboardsResource(googleapiclient.discovery.Resource):
        def get(
            self, *, leaderboardId: str, language: str = ..., **kwargs: typing.Any
        ) -> LeaderboardHttpRequest: ...
        def list(
            self,
            *,
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> LeaderboardListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: LeaderboardListResponseHttpRequest,
            previous_response: LeaderboardListResponse,
        ) -> LeaderboardListResponseHttpRequest | None: ...

    @typing.type_check_only
    class MetagameResource(googleapiclient.discovery.Resource):
        def getMetagameConfig(
            self, **kwargs: typing.Any
        ) -> MetagameConfigHttpRequest: ...
        def listCategoriesByPlayer(
            self,
            *,
            playerId: str,
            collection: typing_extensions.Literal["COLLECTION_UNSPECIFIED", "ALL"],
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> CategoryListResponseHttpRequest: ...
        def listCategoriesByPlayer_next(
            self,
            previous_request: CategoryListResponseHttpRequest,
            previous_response: CategoryListResponse,
        ) -> CategoryListResponseHttpRequest | None: ...

    @typing.type_check_only
    class PlayersResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            playerId: str,
            language: str = ...,
            playerIdConsistencyToken: str = ...,
            **kwargs: typing.Any
        ) -> PlayerHttpRequest: ...
        def getScopedPlayerIds(
            self, **kwargs: typing.Any
        ) -> ScopedPlayerIdsHttpRequest: ...
        def list(
            self,
            *,
            collection: typing_extensions.Literal[
                "CONNECTED", "VISIBLE", "FRIENDS_ALL"
            ],
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> PlayerListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: PlayerListResponseHttpRequest,
            previous_response: PlayerListResponse,
        ) -> PlayerListResponseHttpRequest | None: ...

    @typing.type_check_only
    class RevisionsResource(googleapiclient.discovery.Resource):
        def check(
            self, *, clientRevision: str, **kwargs: typing.Any
        ) -> RevisionCheckResponseHttpRequest: ...

    @typing.type_check_only
    class ScoresResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            playerId: str,
            leaderboardId: str,
            timeSpan: typing_extensions.Literal[
                "SCORE_TIME_SPAN_UNSPECIFIED", "ALL", "ALL_TIME", "WEEKLY", "DAILY"
            ],
            includeRankType: typing_extensions.Literal[
                "INCLUDE_RANK_TYPE_UNSPECIFIED", "ALL", "PUBLIC", "SOCIAL", "FRIENDS"
            ] = ...,
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> PlayerLeaderboardScoreListResponseHttpRequest: ...
        def get_next(
            self,
            previous_request: PlayerLeaderboardScoreListResponseHttpRequest,
            previous_response: PlayerLeaderboardScoreListResponse,
        ) -> PlayerLeaderboardScoreListResponseHttpRequest | None: ...
        def list(
            self,
            *,
            leaderboardId: str,
            collection: typing_extensions.Literal[
                "SCORE_COLLECTION_UNSPECIFIED", "PUBLIC", "SOCIAL", "FRIENDS"
            ],
            timeSpan: typing_extensions.Literal[
                "SCORE_TIME_SPAN_UNSPECIFIED", "ALL_TIME", "WEEKLY", "DAILY"
            ],
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> LeaderboardScoresHttpRequest: ...
        def list_next(
            self,
            previous_request: LeaderboardScoresHttpRequest,
            previous_response: LeaderboardScores,
        ) -> LeaderboardScoresHttpRequest | None: ...
        def listWindow(
            self,
            *,
            leaderboardId: str,
            collection: typing_extensions.Literal[
                "SCORE_COLLECTION_UNSPECIFIED", "PUBLIC", "SOCIAL", "FRIENDS"
            ],
            timeSpan: typing_extensions.Literal[
                "SCORE_TIME_SPAN_UNSPECIFIED", "ALL_TIME", "WEEKLY", "DAILY"
            ],
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            resultsAbove: int = ...,
            returnTopIfAbsent: bool = ...,
            **kwargs: typing.Any
        ) -> LeaderboardScoresHttpRequest: ...
        def listWindow_next(
            self,
            previous_request: LeaderboardScoresHttpRequest,
            previous_response: LeaderboardScores,
        ) -> LeaderboardScoresHttpRequest | None: ...
        def submit(
            self,
            *,
            leaderboardId: str,
            score: str,
            language: str = ...,
            scoreTag: str = ...,
            **kwargs: typing.Any
        ) -> PlayerScoreResponseHttpRequest: ...
        def submitMultiple(
            self,
            *,
            body: PlayerScoreSubmissionList = ...,
            language: str = ...,
            **kwargs: typing.Any
        ) -> PlayerScoreListResponseHttpRequest: ...

    @typing.type_check_only
    class SnapshotsResource(googleapiclient.discovery.Resource):
        def get(
            self, *, snapshotId: str, language: str = ..., **kwargs: typing.Any
        ) -> SnapshotHttpRequest: ...
        def list(
            self,
            *,
            playerId: str,
            language: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> SnapshotListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: SnapshotListResponseHttpRequest,
            previous_response: SnapshotListResponse,
        ) -> SnapshotListResponseHttpRequest | None: ...

    @typing.type_check_only
    class StatsResource(googleapiclient.discovery.Resource):
        def get(self, **kwargs: typing.Any) -> StatsResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def achievementDefinitions(self) -> AchievementDefinitionsResource: ...
    def achievements(self) -> AchievementsResource: ...
    def applications(self) -> ApplicationsResource: ...
    def events(self) -> EventsResource: ...
    def leaderboards(self) -> LeaderboardsResource: ...
    def metagame(self) -> MetagameResource: ...
    def players(self) -> PlayersResource: ...
    def revisions(self) -> RevisionsResource: ...
    def scores(self) -> ScoresResource: ...
    def snapshots(self) -> SnapshotsResource: ...
    def stats(self) -> StatsResource: ...

@typing.type_check_only
class AchievementDefinitionsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementDefinitionsListResponse: ...

@typing.type_check_only
class AchievementIncrementResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementIncrementResponse: ...

@typing.type_check_only
class AchievementRevealResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementRevealResponse: ...

@typing.type_check_only
class AchievementSetStepsAtLeastResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementSetStepsAtLeastResponse: ...

@typing.type_check_only
class AchievementUnlockResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementUnlockResponse: ...

@typing.type_check_only
class AchievementUpdateMultipleResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementUpdateMultipleResponse: ...

@typing.type_check_only
class ApplicationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Application: ...

@typing.type_check_only
class ApplicationVerifyResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ApplicationVerifyResponse: ...

@typing.type_check_only
class CategoryListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CategoryListResponse: ...

@typing.type_check_only
class EndPointHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EndPoint: ...

@typing.type_check_only
class EventDefinitionListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EventDefinitionListResponse: ...

@typing.type_check_only
class EventUpdateResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EventUpdateResponse: ...

@typing.type_check_only
class LeaderboardHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Leaderboard: ...

@typing.type_check_only
class LeaderboardListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LeaderboardListResponse: ...

@typing.type_check_only
class LeaderboardScoresHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LeaderboardScores: ...

@typing.type_check_only
class MetagameConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MetagameConfig: ...

@typing.type_check_only
class PlayerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Player: ...

@typing.type_check_only
class PlayerAchievementListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PlayerAchievementListResponse: ...

@typing.type_check_only
class PlayerEventListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PlayerEventListResponse: ...

@typing.type_check_only
class PlayerLeaderboardScoreListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PlayerLeaderboardScoreListResponse: ...

@typing.type_check_only
class PlayerListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PlayerListResponse: ...

@typing.type_check_only
class PlayerScoreListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PlayerScoreListResponse: ...

@typing.type_check_only
class PlayerScoreResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PlayerScoreResponse: ...

@typing.type_check_only
class RevisionCheckResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RevisionCheckResponse: ...

@typing.type_check_only
class ScopedPlayerIdsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ScopedPlayerIds: ...

@typing.type_check_only
class SnapshotHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Snapshot: ...

@typing.type_check_only
class SnapshotListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SnapshotListResponse: ...

@typing.type_check_only
class StatsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StatsResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AcceptInvitationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Account(typing_extensions.TypedDict, total=False):
    accountName: str
    accountNumber: str
    name: str
    organizationInfo: OrganizationInfo
    permissionLevel: typing_extensions.Literal[
        "PERMISSION_LEVEL_UNSPECIFIED", "OWNER_LEVEL", "MEMBER_LEVEL"
    ]
    primaryOwner: str
    role: typing_extensions.Literal[
        "ACCOUNT_ROLE_UNSPECIFIED", "PRIMARY_OWNER", "OWNER", "MANAGER", "SITE_MANAGER"
    ]
    type: typing_extensions.Literal[
        "ACCOUNT_TYPE_UNSPECIFIED",
        "PERSONAL",
        "LOCATION_GROUP",
        "USER_GROUP",
        "ORGANIZATION",
    ]
    verificationState: typing_extensions.Literal[
        "VERIFICATION_STATE_UNSPECIFIED",
        "VERIFIED",
        "UNVERIFIED",
        "VERIFICATION_REQUESTED",
    ]
    vettedState: typing_extensions.Literal[
        "VETTED_STATE_UNSPECIFIED", "NOT_VETTED", "VETTED", "INVALID"
    ]

@typing.type_check_only
class Admin(typing_extensions.TypedDict, total=False):
    account: str
    admin: str
    name: str
    pendingInvitation: bool
    role: typing_extensions.Literal[
        "ADMIN_ROLE_UNSPECIFIED", "PRIMARY_OWNER", "OWNER", "MANAGER", "SITE_MANAGER"
    ]

@typing.type_check_only
class DeclineInvitationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Invitation(typing_extensions.TypedDict, total=False):
    name: str
    role: typing_extensions.Literal[
        "ADMIN_ROLE_UNSPECIFIED", "PRIMARY_OWNER", "OWNER", "MANAGER", "SITE_MANAGER"
    ]
    targetAccount: Account
    targetLocation: TargetLocation
    targetType: typing_extensions.Literal[
        "TARGET_TYPE_UNSPECIFIED", "ACCOUNTS_ONLY", "LOCATIONS_ONLY"
    ]

@typing.type_check_only
class ListAccountAdminsResponse(typing_extensions.TypedDict, total=False):
    accountAdmins: _list[Admin]

@typing.type_check_only
class ListAccountsResponse(typing_extensions.TypedDict, total=False):
    accounts: _list[Account]
    nextPageToken: str

@typing.type_check_only
class ListInvitationsResponse(typing_extensions.TypedDict, total=False):
    invitations: _list[Invitation]

@typing.type_check_only
class ListLocationAdminsResponse(typing_extensions.TypedDict, total=False):
    admins: _list[Admin]

@typing.type_check_only
class OrganizationInfo(typing_extensions.TypedDict, total=False):
    address: PostalAddress
    phoneNumber: str
    registeredDomain: str

@typing.type_check_only
class PostalAddress(typing_extensions.TypedDict, total=False):
    addressLines: _list[str]
    administrativeArea: str
    languageCode: str
    locality: str
    organization: str
    postalCode: str
    recipients: _list[str]
    regionCode: str
    revision: int
    sortingCode: str
    sublocality: str

@typing.type_check_only
class TargetLocation(typing_extensions.TypedDict, total=False):
    address: str
    locationName: str

@typing.type_check_only
class TransferLocationRequest(typing_extensions.TypedDict, total=False):
    destinationAccount: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class CreateAuthUriResponse(typing_extensions.TypedDict, total=False):
    allProviders: _list[str]
    authUri: str
    captchaRequired: bool
    forExistingProvider: bool
    kind: str
    providerId: str
    registered: bool
    sessionId: str
    signinMethods: _list[str]

@typing.type_check_only
class DeleteAccountResponse(typing_extensions.TypedDict, total=False):
    kind: str

@typing.type_check_only
class DownloadAccountResponse(typing_extensions.TypedDict, total=False):
    kind: str
    nextPageToken: str
    users: _list[UserInfo]

@typing.type_check_only
class EmailLinkSigninResponse(typing_extensions.TypedDict, total=False):
    email: str
    expiresIn: str
    idToken: str
    isNewUser: bool
    kind: str
    localId: str
    refreshToken: str

AlternativeEmailTemplate = typing_extensions.TypedDict(
    "AlternativeEmailTemplate",
    {
        "body": str,
        "format": str,
        "from": str,
        "fromDisplayName": str,
        "replyTo": str,
        "subject": str,
    },
    total=False,
)

@typing.type_check_only
class EmailTemplate(AlternativeEmailTemplate): ...

@typing.type_check_only
class GetAccountInfoResponse(typing_extensions.TypedDict, total=False):
    kind: str
    users: _list[UserInfo]

@typing.type_check_only
class GetOobConfirmationCodeResponse(typing_extensions.TypedDict, total=False):
    email: str
    kind: str
    oobCode: str

@typing.type_check_only
class GetRecaptchaParamResponse(typing_extensions.TypedDict, total=False):
    kind: str
    recaptchaSiteKey: str
    recaptchaStoken: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyCreateAuthUriRequest(
    typing_extensions.TypedDict, total=False
):
    appId: str
    authFlowType: str
    clientId: str
    context: str
    continueUri: str
    customParameter: dict[str, typing.Any]
    hostedDomain: str
    identifier: str
    oauthConsumerKey: str
    oauthScope: str
    openidRealm: str
    otaApp: str
    providerId: str
    sessionId: str
    tenantId: str
    tenantProjectNumber: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyDeleteAccountRequest(
    typing_extensions.TypedDict, total=False
):
    delegatedProjectNumber: str
    idToken: str
    localId: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyDownloadAccountRequest(
    typing_extensions.TypedDict, total=False
):
    delegatedProjectNumber: str
    maxResults: int
    nextPageToken: str
    targetProjectId: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyEmailLinkSigninRequest(
    typing_extensions.TypedDict, total=False
):
    email: str
    idToken: str
    oobCode: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyGetAccountInfoRequest(
    typing_extensions.TypedDict, total=False
):
    delegatedProjectNumber: str
    email: _list[str]
    idToken: str
    localId: _list[str]
    phoneNumber: _list[str]

@typing.type_check_only
class IdentitytoolkitRelyingpartyGetProjectConfigResponse(
    typing_extensions.TypedDict, total=False
):
    allowPasswordUser: bool
    apiKey: str
    authorizedDomains: _list[str]
    changeEmailTemplate: EmailTemplate
    dynamicLinksDomain: str
    enableAnonymousUser: bool
    idpConfig: _list[IdpConfig]
    legacyResetPasswordTemplate: EmailTemplate
    projectId: str
    resetPasswordTemplate: EmailTemplate
    useEmailSending: bool
    verifyEmailTemplate: EmailTemplate

@typing.type_check_only
class IdentitytoolkitRelyingpartyGetPublicKeysResponse(dict[str, typing.Any]): ...

@typing.type_check_only
class IdentitytoolkitRelyingpartyResetPasswordRequest(
    typing_extensions.TypedDict, total=False
):
    email: str
    newPassword: str
    oldPassword: str
    oobCode: str

@typing.type_check_only
class IdentitytoolkitRelyingpartySendVerificationCodeRequest(
    typing_extensions.TypedDict, total=False
):
    iosReceipt: str
    iosSecret: str
    phoneNumber: str
    recaptchaToken: str

@typing.type_check_only
class IdentitytoolkitRelyingpartySendVerificationCodeResponse(
    typing_extensions.TypedDict, total=False
):
    sessionInfo: str

@typing.type_check_only
class IdentitytoolkitRelyingpartySetAccountInfoRequest(
    typing_extensions.TypedDict, total=False
):
    captchaChallenge: str
    captchaResponse: str
    createdAt: str
    customAttributes: str
    delegatedProjectNumber: str
    deleteAttribute: _list[str]
    deleteProvider: _list[str]
    disableUser: bool
    displayName: str
    email: str
    emailVerified: bool
    idToken: str
    instanceId: str
    lastLoginAt: str
    localId: str
    oobCode: str
    password: str
    phoneNumber: str
    photoUrl: str
    provider: _list[str]
    returnSecureToken: bool
    upgradeToFederatedLogin: bool
    validSince: str

@typing.type_check_only
class IdentitytoolkitRelyingpartySetProjectConfigRequest(
    typing_extensions.TypedDict, total=False
):
    allowPasswordUser: bool
    apiKey: str
    authorizedDomains: _list[str]
    changeEmailTemplate: EmailTemplate
    delegatedProjectNumber: str
    enableAnonymousUser: bool
    idpConfig: _list[IdpConfig]
    legacyResetPasswordTemplate: EmailTemplate
    resetPasswordTemplate: EmailTemplate
    useEmailSending: bool
    verifyEmailTemplate: EmailTemplate

@typing.type_check_only
class IdentitytoolkitRelyingpartySetProjectConfigResponse(
    typing_extensions.TypedDict, total=False
):
    projectId: str

@typing.type_check_only
class IdentitytoolkitRelyingpartySignOutUserRequest(
    typing_extensions.TypedDict, total=False
):
    instanceId: str
    localId: str

@typing.type_check_only
class IdentitytoolkitRelyingpartySignOutUserResponse(
    typing_extensions.TypedDict, total=False
):
    localId: str

@typing.type_check_only
class IdentitytoolkitRelyingpartySignupNewUserRequest(
    typing_extensions.TypedDict, total=False
):
    captchaChallenge: str
    captchaResponse: str
    disabled: bool
    displayName: str
    email: str
    emailVerified: bool
    idToken: str
    instanceId: str
    localId: str
    password: str
    phoneNumber: str
    photoUrl: str
    tenantId: str
    tenantProjectNumber: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyUploadAccountRequest(
    typing_extensions.TypedDict, total=False
):
    allowOverwrite: bool
    blockSize: int
    cpuMemCost: int
    delegatedProjectNumber: str
    dkLen: int
    hashAlgorithm: str
    memoryCost: int
    parallelization: int
    rounds: int
    saltSeparator: str
    sanityCheck: bool
    signerKey: str
    targetProjectId: str
    users: _list[UserInfo]

@typing.type_check_only
class IdentitytoolkitRelyingpartyVerifyAssertionRequest(
    typing_extensions.TypedDict, total=False
):
    autoCreate: bool
    delegatedProjectNumber: str
    idToken: str
    instanceId: str
    pendingIdToken: str
    postBody: str
    requestUri: str
    returnIdpCredential: bool
    returnRefreshToken: bool
    returnSecureToken: bool
    sessionId: str
    tenantId: str
    tenantProjectNumber: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyVerifyCustomTokenRequest(
    typing_extensions.TypedDict, total=False
):
    delegatedProjectNumber: str
    instanceId: str
    returnSecureToken: bool
    token: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyVerifyPasswordRequest(
    typing_extensions.TypedDict, total=False
):
    captchaChallenge: str
    captchaResponse: str
    delegatedProjectNumber: str
    email: str
    idToken: str
    instanceId: str
    password: str
    pendingIdToken: str
    returnSecureToken: bool
    tenantId: str
    tenantProjectNumber: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyVerifyPhoneNumberRequest(
    typing_extensions.TypedDict, total=False
):
    code: str
    idToken: str
    operation: str
    phoneNumber: str
    sessionInfo: str
    temporaryProof: str
    verificationProof: str

@typing.type_check_only
class IdentitytoolkitRelyingpartyVerifyPhoneNumberResponse(
    typing_extensions.TypedDict, total=False
):
    expiresIn: str
    idToken: str
    isNewUser: bool
    localId: str
    phoneNumber: str
    refreshToken: str
    temporaryProof: str
    temporaryProofExpiresIn: str
    verificationProof: str
    verificationProofExpiresIn: str

@typing.type_check_only
class IdpConfig(typing_extensions.TypedDict, total=False):
    clientId: str
    enabled: bool
    experimentPercent: int
    provider: str
    secret: str
    whitelistedAudiences: _list[str]

@typing.type_check_only
class Relyingparty(typing_extensions.TypedDict, total=False):
    androidInstallApp: bool
    androidMinimumVersion: str
    androidPackageName: str
    canHandleCodeInApp: bool
    captchaResp: str
    challenge: str
    continueUrl: str
    email: str
    iOSAppStoreId: str
    iOSBundleId: str
    idToken: str
    kind: str
    newEmail: str
    requestType: str
    userIp: str

@typing.type_check_only
class ResetPasswordResponse(typing_extensions.TypedDict, total=False):
    email: str
    kind: str
    newEmail: str
    requestType: str

@typing.type_check_only
class SetAccountInfoResponse(typing_extensions.TypedDict, total=False):
    displayName: str
    email: str
    emailVerified: bool
    expiresIn: str
    idToken: str
    kind: str
    localId: str
    newEmail: str
    passwordHash: str
    photoUrl: str
    providerUserInfo: _list[dict[str, typing.Any]]
    refreshToken: str

@typing.type_check_only
class SignupNewUserResponse(typing_extensions.TypedDict, total=False):
    displayName: str
    email: str
    expiresIn: str
    idToken: str
    kind: str
    localId: str
    refreshToken: str

@typing.type_check_only
class UploadAccountResponse(typing_extensions.TypedDict, total=False):
    error: _list[dict[str, typing.Any]]
    kind: str

@typing.type_check_only
class UserInfo(typing_extensions.TypedDict, total=False):
    createdAt: str
    customAttributes: str
    customAuth: bool
    disabled: bool
    displayName: str
    email: str
    emailVerified: bool
    lastLoginAt: str
    localId: str
    passwordHash: str
    passwordUpdatedAt: float
    phoneNumber: str
    photoUrl: str
    providerUserInfo: _list[dict[str, typing.Any]]
    rawPassword: str
    salt: str
    screenName: str
    validSince: str
    version: int

@typing.type_check_only
class VerifyAssertionResponse(typing_extensions.TypedDict, total=False):
    action: str
    appInstallationUrl: str
    appScheme: str
    context: str
    dateOfBirth: str
    displayName: str
    email: str
    emailRecycled: bool
    emailVerified: bool
    errorMessage: str
    expiresIn: str
    federatedId: str
    firstName: str
    fullName: str
    idToken: str
    inputEmail: str
    isNewUser: bool
    kind: str
    language: str
    lastName: str
    localId: str
    needConfirmation: bool
    needEmail: bool
    nickName: str
    oauthAccessToken: str
    oauthAuthorizationCode: str
    oauthExpireIn: int
    oauthIdToken: str
    oauthRequestToken: str
    oauthScope: str
    oauthTokenSecret: str
    originalEmail: str
    photoUrl: str
    providerId: str
    rawUserInfo: str
    refreshToken: str
    screenName: str
    timeZone: str
    verifiedProvider: _list[str]

@typing.type_check_only
class VerifyCustomTokenResponse(typing_extensions.TypedDict, total=False):
    expiresIn: str
    idToken: str
    isNewUser: bool
    kind: str
    refreshToken: str

@typing.type_check_only
class VerifyPasswordResponse(typing_extensions.TypedDict, total=False):
    displayName: str
    email: str
    expiresIn: str
    idToken: str
    kind: str
    localId: str
    oauthAccessToken: str
    oauthAuthorizationCode: str
    oauthExpireIn: int
    photoUrl: str
    refreshToken: str
    registered: bool



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AddGroupMigrationRequest(typing_extensions.TypedDict, total=False):
    migratingVm: str

@typing.type_check_only
class ApplianceVersion(typing_extensions.TypedDict, total=False):
    critical: bool
    releaseNotesUri: str
    uri: str
    version: str

@typing.type_check_only
class AppliedLicense(typing_extensions.TypedDict, total=False):
    osLicense: str
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "NONE", "PAYG", "BYOL"]

@typing.type_check_only
class AvailableUpdates(typing_extensions.TypedDict, total=False):
    inPlaceUpdate: ApplianceVersion
    newDeployableAppliance: ApplianceVersion

@typing.type_check_only
class CancelCloneJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CancelCutoverJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CloneJob(typing_extensions.TypedDict, total=False):
    computeEngineTargetDetails: ComputeEngineTargetDetails
    createTime: str
    endTime: str
    error: Status
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "PENDING",
        "ACTIVE",
        "FAILED",
        "SUCCEEDED",
        "CANCELLED",
        "CANCELLING",
        "ADAPTING_OS",
    ]
    stateTime: str

@typing.type_check_only
class ComputeEngineTargetDefaults(typing_extensions.TypedDict, total=False):
    additionalLicenses: _list[str]
    appliedLicense: AppliedLicense
    bootOption: typing_extensions.Literal[
        "COMPUTE_ENGINE_BOOT_OPTION_UNSPECIFIED",
        "COMPUTE_ENGINE_BOOT_OPTION_EFI",
        "COMPUTE_ENGINE_BOOT_OPTION_BIOS",
    ]
    computeScheduling: ComputeScheduling
    diskType: typing_extensions.Literal[
        "COMPUTE_ENGINE_DISK_TYPE_UNSPECIFIED",
        "COMPUTE_ENGINE_DISK_TYPE_STANDARD",
        "COMPUTE_ENGINE_DISK_TYPE_SSD",
        "COMPUTE_ENGINE_DISK_TYPE_BALANCED",
    ]
    hostname: str
    labels: dict[str, typing.Any]
    licenseType: typing_extensions.Literal[
        "COMPUTE_ENGINE_LICENSE_TYPE_DEFAULT",
        "COMPUTE_ENGINE_LICENSE_TYPE_PAYG",
        "COMPUTE_ENGINE_LICENSE_TYPE_BYOL",
    ]
    machineType: str
    machineTypeSeries: str
    metadata: dict[str, typing.Any]
    networkInterfaces: _list[NetworkInterface]
    networkTags: _list[str]
    secureBoot: bool
    serviceAccount: str
    targetProject: str
    vmName: str
    zone: str

@typing.type_check_only
class ComputeEngineTargetDetails(typing_extensions.TypedDict, total=False):
    additionalLicenses: _list[str]
    appliedLicense: AppliedLicense
    bootOption: typing_extensions.Literal[
        "COMPUTE_ENGINE_BOOT_OPTION_UNSPECIFIED",
        "COMPUTE_ENGINE_BOOT_OPTION_EFI",
        "COMPUTE_ENGINE_BOOT_OPTION_BIOS",
    ]
    computeScheduling: ComputeScheduling
    diskType: typing_extensions.Literal[
        "COMPUTE_ENGINE_DISK_TYPE_UNSPECIFIED",
        "COMPUTE_ENGINE_DISK_TYPE_STANDARD",
        "COMPUTE_ENGINE_DISK_TYPE_SSD",
        "COMPUTE_ENGINE_DISK_TYPE_BALANCED",
    ]
    hostname: str
    labels: dict[str, typing.Any]
    licenseType: typing_extensions.Literal[
        "COMPUTE_ENGINE_LICENSE_TYPE_DEFAULT",
        "COMPUTE_ENGINE_LICENSE_TYPE_PAYG",
        "COMPUTE_ENGINE_LICENSE_TYPE_BYOL",
    ]
    machineType: str
    machineTypeSeries: str
    metadata: dict[str, typing.Any]
    networkInterfaces: _list[NetworkInterface]
    networkTags: _list[str]
    project: str
    secureBoot: bool
    serviceAccount: str
    vmName: str
    zone: str

@typing.type_check_only
class ComputeScheduling(typing_extensions.TypedDict, total=False):
    minNodeCpus: int
    nodeAffinities: _list[SchedulingNodeAffinity]
    onHostMaintenance: typing_extensions.Literal[
        "ON_HOST_MAINTENANCE_UNSPECIFIED", "TERMINATE", "MIGRATE"
    ]
    restartType: typing_extensions.Literal[
        "RESTART_TYPE_UNSPECIFIED", "AUTOMATIC_RESTART", "NO_AUTOMATIC_RESTART"
    ]

@typing.type_check_only
class CutoverJob(typing_extensions.TypedDict, total=False):
    computeEngineTargetDetails: ComputeEngineTargetDetails
    createTime: str
    endTime: str
    error: Status
    name: str
    progressPercent: int
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "PENDING",
        "FAILED",
        "SUCCEEDED",
        "CANCELLED",
        "CANCELLING",
        "ACTIVE",
        "ADAPTING_OS",
    ]
    stateMessage: str
    stateTime: str

@typing.type_check_only
class DatacenterConnector(typing_extensions.TypedDict, total=False):
    applianceInfrastructureVersion: str
    applianceSoftwareVersion: str
    availableVersions: AvailableUpdates
    bucket: str
    createTime: str
    error: Status
    name: str
    registrationId: str
    serviceAccount: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "PENDING", "OFFLINE", "FAILED", "ACTIVE"
    ]
    stateTime: str
    updateTime: str
    upgradeStatus: UpgradeStatus
    version: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class FetchInventoryResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    updateTime: str
    vmwareVms: VmwareVmsDetails

@typing.type_check_only
class FinalizeMigrationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Group(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    displayName: str
    name: str
    updateTime: str

@typing.type_check_only
class Link(typing_extensions.TypedDict, total=False):
    description: str
    url: str

@typing.type_check_only
class ListCloneJobsResponse(typing_extensions.TypedDict, total=False):
    cloneJobs: _list[CloneJob]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListCutoverJobsResponse(typing_extensions.TypedDict, total=False):
    cutoverJobs: _list[CutoverJob]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListDatacenterConnectorsResponse(typing_extensions.TypedDict, total=False):
    datacenterConnectors: _list[DatacenterConnector]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListGroupsResponse(typing_extensions.TypedDict, total=False):
    groups: _list[Group]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListMigratingVmsResponse(typing_extensions.TypedDict, total=False):
    migratingVms: _list[MigratingVm]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListReplicationCyclesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    replicationCycles: _list[ReplicationCycle]
    unreachable: _list[str]

@typing.type_check_only
class ListSourcesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    sources: _list[Source]
    unreachable: _list[str]

@typing.type_check_only
class ListTargetProjectsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    targetProjects: _list[TargetProject]
    unreachable: _list[str]

@typing.type_check_only
class ListUtilizationReportsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    unreachable: _list[str]
    utilizationReports: _list[UtilizationReport]

@typing.type_check_only
class LocalizedMessage(typing_extensions.TypedDict, total=False):
    locale: str
    message: str

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class MigratingVm(typing_extensions.TypedDict, total=False):
    computeEngineTargetDefaults: ComputeEngineTargetDefaults
    createTime: str
    currentSyncInfo: ReplicationCycle
    description: str
    displayName: str
    error: Status
    group: str
    labels: dict[str, typing.Any]
    lastSync: ReplicationSync
    name: str
    policy: SchedulePolicy
    recentCloneJobs: _list[CloneJob]
    recentCutoverJobs: _list[CutoverJob]
    sourceVmId: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "PENDING",
        "READY",
        "FIRST_SYNC",
        "ACTIVE",
        "CUTTING_OVER",
        "CUTOVER",
        "FINAL_SYNC",
        "PAUSED",
        "FINALIZING",
        "FINALIZED",
        "ERROR",
    ]
    stateTime: str
    updateTime: str

@typing.type_check_only
class MigrationError(typing_extensions.TypedDict, total=False):
    actionItem: LocalizedMessage
    code: typing_extensions.Literal[
        "ERROR_CODE_UNSPECIFIED",
        "UNKNOWN_ERROR",
        "SOURCE_VALIDATION_ERROR",
        "SOURCE_REPLICATION_ERROR",
        "TARGET_REPLICATION_ERROR",
        "OS_ADAPTATION_ERROR",
        "CLONE_ERROR",
        "CUTOVER_ERROR",
        "UTILIZATION_REPORT_ERROR",
        "APPLIANCE_UPGRADE_ERROR",
    ]
    errorMessage: LocalizedMessage
    errorTime: str
    helpLinks: _list[Link]

@typing.type_check_only
class NetworkInterface(typing_extensions.TypedDict, total=False):
    externalIp: str
    internalIp: str
    network: str
    subnetwork: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusMessage: str
    target: str
    verb: str

@typing.type_check_only
class PauseMigrationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class RemoveGroupMigrationRequest(typing_extensions.TypedDict, total=False):
    migratingVm: str

@typing.type_check_only
class ReplicationCycle(typing_extensions.TypedDict, total=False):
    progressPercent: int
    startTime: str

@typing.type_check_only
class ReplicationSync(typing_extensions.TypedDict, total=False):
    lastSyncTime: str

@typing.type_check_only
class ResumeMigrationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SchedulePolicy(typing_extensions.TypedDict, total=False):
    idleDuration: str
    skipOsAdaptation: bool

@typing.type_check_only
class SchedulingNodeAffinity(typing_extensions.TypedDict, total=False):
    key: str
    operator: typing_extensions.Literal["OPERATOR_UNSPECIFIED", "IN", "NOT_IN"]
    values: _list[str]

@typing.type_check_only
class Source(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    labels: dict[str, typing.Any]
    name: str
    updateTime: str
    vmware: VmwareSourceDetails

@typing.type_check_only
class StartMigrationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TargetProject(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    name: str
    project: str
    updateTime: str

@typing.type_check_only
class UpgradeApplianceRequest(typing_extensions.TypedDict, total=False):
    requestId: str

@typing.type_check_only
class UpgradeStatus(typing_extensions.TypedDict, total=False):
    error: Status
    previousVersion: str
    startTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "RUNNING", "FAILED", "SUCCEEDED"
    ]
    version: str

@typing.type_check_only
class UtilizationReport(typing_extensions.TypedDict, total=False):
    createTime: str
    displayName: str
    error: Status
    frameEndTime: str
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "CREATING", "SUCCEEDED", "FAILED"
    ]
    stateTime: str
    timeFrame: typing_extensions.Literal[
        "TIME_FRAME_UNSPECIFIED", "WEEK", "MONTH", "YEAR"
    ]
    vmCount: int
    vms: _list[VmUtilizationInfo]

@typing.type_check_only
class VmUtilizationInfo(typing_extensions.TypedDict, total=False):
    utilization: VmUtilizationMetrics
    vmId: str
    vmwareVmDetails: VmwareVmDetails

@typing.type_check_only
class VmUtilizationMetrics(typing_extensions.TypedDict, total=False):
    cpuAveragePercent: int
    cpuMaxPercent: int
    diskIoRateAverageKbps: str
    diskIoRateMaxKbps: str
    memoryAveragePercent: int
    memoryMaxPercent: int
    networkThroughputAverageKbps: str
    networkThroughputMaxKbps: str

@typing.type_check_only
class VmwareSourceDetails(typing_extensions.TypedDict, total=False):
    password: str
    thumbprint: str
    username: str
    vcenterIp: str

@typing.type_check_only
class VmwareVmDetails(typing_extensions.TypedDict, total=False):
    bootOption: typing_extensions.Literal["BOOT_OPTION_UNSPECIFIED", "EFI", "BIOS"]
    committedStorageMb: str
    cpuCount: int
    datacenterDescription: str
    datacenterId: str
    diskCount: int
    displayName: str
    guestDescription: str
    memoryMb: int
    powerState: typing_extensions.Literal[
        "POWER_STATE_UNSPECIFIED", "ON", "OFF", "SUSPENDED"
    ]
    uuid: str
    vmId: str

@typing.type_check_only
class VmwareVmsDetails(typing_extensions.TypedDict, total=False):
    details: _list[VmwareVmDetails]
